@@ -19,11 +19,20 @@ def dead(process):
 
 
 def start():
-    logging.debug("start")
-    gps = ProcessManager("GPS Client", ["gps_client"]).start()
-    mc3 = ProcessManager("MC3 Integration", ["mc3_integration"]).start()
-    interface = ProcessManager("Interface", ["mission_controller"]).start()
-    processes = (gps, mc3, interface)
+    logging.debug("starting processes")
+
+    processes = (
+        ProcessManager("Interface Server", ["mission_controller"]),
+        ProcessManager("GPS Client", ["gps_client"]),
+        ProcessManager("MC3 Integration", ["mc3_integration"]),
+    )
+
+    for p in processes:
+        p.start()
+        time.sleep(2)
+
+    ProcessManager(args=["start", "chrome", "http://127.0.0.1/app/"]).start()
+
     try:
         while True:
             time.sleep(5)
@@ -34,4 +43,5 @@ def start():
     finally:
         for p in processes:
             p.shutdown()
+
     logging.info("All processes Exited")
